[![pypi](https://img.shields.io/pypi/v/youtube-search-requests?style=plastic&logo=appveyor)](https://pypi.org/project/youtube-search-requests)
[![python-ver](https://img.shields.io/pypi/pyversions/youtube-search-requests?style=plastic&logo=appveyor)](https://pypi.org/project/youtube-search-requests)
[![github-release](https://img.shields.io/github/v/release/trollfist20/youtube-search-requests?style=plastic&logo=appveyor)](https://github.com/trollfist20/youtube-search-requests/releases)
[![pypi-total-downloads](https://img.shields.io/pypi/dm/youtube-search-requests?label=DOWNLOADS&style=plastic&logo=appveyor)](https://pypi.org/project/youtube-search-requests)


# youtube-search-requests
### Search Youtube videos using python requests without Youtube API.
### youtube-search-requests can search unlimited videos !!!

## Installation
```
pip install youtube-search-requests
```

### CLI (Command Line Interface) Usage:
```bash

ysr "fish" --json

# or

youtube-search-requests "fish" --json

# do this if "ysr" and "youtube_search_requests" didn't work
python3 -m youtube_search_requests "fish" --json

# Output: {"urls": {'title': ..., 'url': 'https://www.youtube.com/watch?v=0gT8Ty0ClHc', thumbnails: [...], ...}}

```

### Usage

- For version v0.1.0 Upper [click here](https://github.com/mansuf/youtube-search-requests/blob/main/docs/v0.1.0%20upper/Usage.md)

- For version v0.1.0 Lower [click here](https://github.com/mansuf/youtube-search-requests/blob/main/docs/v0.1.0%20lower/Usage.md)

